/************************************************
* TABMAN.C - tab handling functions.			*
*												*
* 900424 MCMason - written for MSC v5.1			*
************************************************/

#define TABMAN
#include "tab.h"

/************************************************
* detab - copy the input string to the output	*
* string while expanding the tabs to spaces.	*
*												*
* INP:	in - ptr to input text					*
*		out - ptr to output buffer				*
* NOTE:	it is assumed that the output buffer is	*
*		large enough to hold the string!		*
************************************************/
void detab(char in[], char out[])
	{
	int	i,j;

	for (i=j=0; in[i]; i++)		/* for each char*/
		if (in[i] != '\t')		/* If not a tab	*/
			out[j++] = in[i];	/* move to out	*/
		else					/* else output	*/
			do	{				/* spaces until	*/
				out[j++] = ' ';	/* tabstop found*/
				} while (!isTab(j));
	out[j]=0;			/* Terminate the string	*/
	}

/************************************************
* entab - copy the input string to the output	*
* string, compressing spaces into tabs, where	*
* appropriate.									*
*												*
* INP:	in - ptr to input buffer				*
*		out - ptr to output buffer				*
* NOTE:	tabs in the input stream are echoed to	*
*		the output string, and will cause any	*
*		subsequent tabs to be misplaced.  This	*
*		can be avoided by detabbing the string	*
*		before entabbing it.					*
************************************************/
void entab(char in[], char out[])
	{
	int i,j,cs;

	for (i=j=0; in[i]; )		/* for each char*/
		if (in[i] != ' ')		/* if not space	*/
			out[j++] = in[i++];	/* output it	*/
		else					/* else, keep	*/
			{					/* checking chrs*/
			for (cs=0; in[i++]==' '; )
				if (isTab(i))	/* and while ' '*/
					{			/* output tabs  */
					out[j++] = '\t';
					cs=0;		/* at stops, and*/
					}			/* zero spc cnt	*/
				else ++cs;
			while (cs-- > 0)	/* When end of	*/
				out[j++] = ' ';	/* ' ', output	*/
			--i;				/* ' ' to get to*/
			}					/* current col.	*/
	out[j]=0;				/* terminate string	*/
	}
